==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'Adaugaţi un document',
	'bouton_ajouter_image' => 'Adăugaţi o imagine',
	'bouton_ajouter_image_document' => 'Adăugaţi o imagine sau un document',

	// D
	'double_clic_inserer_doc' => 'Faceţi dublu-clic pentru a insera această scurtătură în text',

	// E
	'entree_dimensions' => 'Dimensiuni :',
	'entree_titre_document' => 'Titlul documentului :',
	'entree_titre_image' => 'Titlul imaginii :',

	// I
	'image_tourner_180' => 'Rotaţie 180°',
	'image_tourner_droite' => 'Rotaţie 90° la dreapta',
	'image_tourner_gauche' => 'Rotaţie 90° la stânga',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Acest document nu este disponibil',
	'info_documents' => 'Documente',
	'info_inclusion_directe' => 'Includere directă :',
	'info_inclusion_vignette' => 'Includerea vinietei :',
	'info_installer_tous_documents' => 'Instalaţi toate documentele',
	'info_logo_max_taille' => 'Viniétele trebuie în mod obligatoriu să fie mai mici de @maxi@ (acest fişier are @actuel@).',
	'info_portfolio' => 'Portofoliu',
	'info_referencer_doc_distant' => 'Referenţiaţi un document pe internet :',
	'info_telecharger' => 'Încărcaţi de pe calculatorul dumneavoastră :',
	'item_autoriser_selectionner_date_en_ligne' => 'Permiteţi modificarea datei fiecărui document',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Data documentelor este cea a adăugării lor pe site',

	// T
	'texte_documents_joints' => 'Puteţi autoriza adăugarea de documente (fişiere de birotică, imagini, fişiere multimedia, ş.a.m.d.)
   în articole sau rubrici. Aceste fişiere pot fi referenţiate în cadrul articolelor sau afişate separat.
', # MODIF
	'texte_documents_joints_2' => 'Aceast reglaj nu împiedică adăugarea de imagini direct în articole.', # MODIF
	'titre_documents_joints' => 'Documente ataşate',
	'tout_dossier_upload' => 'Tot dosarul @upload@',

	// U
	'upload_fichier_zip' => 'Fişier ZIP',
	'upload_fichier_zip_texte' => 'Fişierul pe care propuneţi spre instalare este un fişier ZIP.',
	'upload_fichier_zip_texte2' => 'Acest fişier poate fi :',
	'upload_limit' => 'Acest fişier este prea mare pentru server ; talia maximală autorizată în directorul <i>upload</i> este de @max@.',
	'upload_zip_conserver' => 'Conservaţi arhiva după extracţie', # MODIF
	'upload_zip_decompacter' => 'decomprimat şi fiecare element conţinut instalat pe site. Fişierele care vor fi instalate pe site sunt :',
	'upload_zip_telquel' => 'instalat ca atare, ca arhivă comprimată ZIP ;',
	'upload_zip_titrer' => 'Titraţi după numele fişierelor'
);

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ro
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'Adaugaţi un document',
	'bouton_ajouter_image' => 'Adăugaţi o imagine',
	'bouton_ajouter_image_document' => 'Adăugaţi o imagine sau un document',

	// D
	'double_clic_inserer_doc' => 'Faceţi dublu-clic pentru a insera această scurtătură în text',

	// E
	'entree_dimensions' => 'Dimensiuni :',
	'entree_titre_document' => 'Titlul documentului :',
	'entree_titre_image' => 'Titlul imaginii :',

	// I
	'image_tourner_180' => 'Rotaţie 180°',
	'image_tourner_droite' => 'Rotaţie 90° la dreapta',
	'image_tourner_gauche' => 'Rotaţie 90° la stânga',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Acest document nu este disponibil',
	'info_documents' => 'Documente',
	'info_inclusion_directe' => 'Includere directă :',
	'info_inclusion_vignette' => 'Includerea vinietei :',
	'info_installer_tous_documents' => 'Instalaţi toate documentele',
	'info_logo_max_taille' => 'Viniétele trebuie în mod obligatoriu să fie mai mici de @maxi@ (acest fişier are @actuel@).',
	'info_portfolio' => 'Portofoliu',
	'info_referencer_doc_distant' => 'Referenţiaţi un document pe internet :',
	'info_telecharger' => 'Încărcaţi de pe calculatorul dumneavoastră :',
	'item_autoriser_selectionner_date_en_ligne' => 'Permiteţi modificarea datei fiecărui document',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Data documentelor este cea a adăugării lor pe site',

	// T
	'texte_documents_joints' => 'Puteţi autoriza adăugarea de documente (fişiere de birotică, imagini, fişiere multimedia, ş.a.m.d.)
   în articole sau rubrici. Aceste fişiere pot fi referenţiate în cadrul articolelor sau afişate separat.
', # MODIF
	'texte_documents_joints_2' => 'Aceast reglaj nu împiedică adăugarea de imagini direct în articole.', # MODIF
	'titre_documents_joints' => 'Documente ataşate',
	'tout_dossier_upload' => 'Tot dosarul @upload@',

	// U
	'upload_fichier_zip' => 'Fişier ZIP',
	'upload_fichier_zip_texte' => 'Fişierul pe care propuneţi spre instalare este un fişier ZIP.',
	'upload_fichier_zip_texte2' => 'Acest fişier poate fi :',
	'upload_limit' => 'Acest fişier este prea mare pentru server ; talia maximală autorizată în directorul <i>upload</i> este de @max@.',
	'upload_zip_conserver' => 'Conservaţi arhiva după extracţie', # MODIF
	'upload_zip_decompacter' => 'decomprimat şi fiecare element conţinut instalat pe site. Fişierele care vor fi instalate pe site sunt :',
	'upload_zip_telquel' => 'instalat ca atare, ca arhivă comprimată ZIP ;',
	'upload_zip_titrer' => 'Titraţi după numele fişierelor',
];
